import {
  StyleSheet,
  Text,
  ScrollView,
  TouchableWithoutFeedback,
  SafeAreaView,
  FlatList,
  TextInput,
} from 'react-native';
import React, { useCallback, useEffect, useState } from 'react';
import { Provider as ProviderComponent } from 'react-native-paper';
import Contacts from 'react-native-contacts';
import numerosregistrados from '../datos/numerosregistrados.json';
import { useNavigation } from '@react-navigation/native';
import { View, Pressable, Alert } from 'react-native';
import { PermissionsAndroid } from 'react-native';
export interface PhoneNumbers {
  number: string | undefined;
}
export interface DatosContactos {
  displayName?: string;
  phoneNumbers?: PhoneNumbers[];
  isNumberRegistered?: boolean;
}
export interface DatosNumberContactos {
  number: string;
}

export const ContactosPagar = () => {
  const [ContactosUsuario, setContactosUsuario] = useState<any>();
  const [searchList, setSearchList] = useState<any[]>();
  const navigate = useNavigation<any>();
  const render=useCallback(({ item }:any) => {
    if (item.isNumberRegistered == 1) {
      return (
        <TouchableWithoutFeedback
          onPress={() =>
            navigate.navigate('PayRecibe', {
              name: item.displayName,
              number: item.phoneNumbers![0]?.number,
            })
          }
        >
          <View style={styles.container}>
            <Text>{item.displayName}</Text>
            <Text>{item.phoneNumbers![0]?.number}</Text>
          </View>
        </TouchableWithoutFeedback>
      );
    } else {
      return (
        <View style={{ ...styles.container, backgroundColor: 'pink' }}>
          <View style={styles.contacto}>
            <Text>{item.displayName}</Text>
            <Text>{item.phoneNumbers![0]?.number}</Text>
          </View>
          <View style={styles.containerInvitar}>
            <Pressable
              onPress={() =>
                Alert.alert(
                  'Se envio la invitacion al usuario satisfactoriamente '
                )
              }
            >
              <Text style={styles.textoInvitar}>Invitar</Text>
            </Pressable>
          </View>
        </View>
      );
    }
  },[])
  useEffect(() => {
    PermissionsAndroid.request(PermissionsAndroid.PERMISSIONS.READ_CONTACTS!, {
      title: 'Contacts',
      message: 'This app would like to view your contacts.',
      buttonPositive: 'Please accept bare mortal',
    })
      .then(() => {
        Contacts.getAll().then((contacts) => {
          const contactos: DatosContactos[] = contacts.map(
            (item: DatosContactos) => ({
              displayName: item.displayName,
              phoneNumbers: item.phoneNumbers,
              isNumberRegistered: numerosregistrados.some(
                (dato: DatosNumberContactos) =>
                  dato.number.replace(/\s+/g, '') ==
                  item.phoneNumbers![0]?.number?.replace(/\s+/g, '')
              ),
            })
          );
          setContactosUsuario(contactos);
          setSearchList(contactos);
        });
      })
      .catch((e) => {
        Alert.alert('Error', 'No se puede acceder a los contactos' + e);
      });

    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const findContact = useCallback(
    (text: string) => {
      if (text) {
        const newData = ContactosUsuario.filter((item: DatosContactos) => {
          const itemData = item.displayName
            ? item.displayName.toUpperCase()
            : ''.toUpperCase();
          const textData = text.toUpperCase();
          return itemData.indexOf(textData) > -1;
        });
        setSearchList(newData);
      } else {
        setSearchList(ContactosUsuario);
      }
    },
    [ContactosUsuario]
  );
  return (
    <ProviderComponent>
      <ScrollView style={styles.container1}>
        <SafeAreaView style={styles.containerFinder}>
          <Text style={{ color: 'white', margin: 10 }}>Buscar Contactos</Text>
          <TextInput style={styles.input} onChangeText={findContact} />
        </SafeAreaView>
        <Pressable onPress={()=>navigate.navigate("CamaraQrNavigate")}>
          <Text>Pagar por Qr</Text>
        </Pressable>
        <FlatList
          data={searchList?.sort(
            (a: DatosContactos, b: DatosContactos) =>
              Number(b.isNumberRegistered) - Number(a.isNumberRegistered)
          )}
          renderItem={render}
        />
      </ScrollView>
    </ProviderComponent>
  );
};
const styles = StyleSheet.create({
  containerInvitar: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
  },
  textoInvitar: {
    fontWeight: 'bold',
    padding: 8,
    paddingLeft: 15,
    paddingRight: 15,
    borderRadius: 20,
    backgroundColor: '#ea899a',
  },
  container1: {
    flex: 1,
    height: '100%',
  },
  contacto: {
    display: 'flex',
  },
  container: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
    backgroundColor: 'white',
    width: '100%',
    padding: 10,
    shadowColor: '#000',
    shadowOffset: {
      width: 0,
      height: 2,
    },
    shadowOpacity: 0.25,
    shadowRadius: 3.84,
    elevation: 5,
  },
  input: {
    flexBasis: '30%',
    alignContent: 'center',
    height: 40,
    margin: 12,
    borderColor: '#7a42f4',
    borderWidth: 1,
    backgroundColor: 'white',
  },
  containerFinder: {
    flex: 1,
    backgroundColor: '#800080',
    width: '100%',
    height: '100%',
    padding: 10,
    shadowColor: '#000',
    shadowOffset: {
      width: 0,
      height: 2,
    },
    shadowOpacity: 0.25,
    shadowRadius: 3.84,
    elevation: 5,
  },
});
